@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Any, Callable, Iterable, Optional, Literal, Type, overload, TYPE_CHECKING
+from typing import Any, Callable, Iterable, Optional, Literal, Type, Union, overload, TYPE_CHECKING, TypeVar
 from enum import Enum
 from abc import abstractmethod, ABC
 
@@ -8,12 +8,16 @@ from ormlambda.common.enums import JoinType
 
 if TYPE_CHECKING:
     from ormlambda import Table
+    from .IAggregate import IAggregate
 
 OrderType = Literal["ASC", "DESC"]
 
 # TODOH: This var is duplicated from 'src\ormlambda\databases\my_sql\clauses\create_database.py'
 TypeExists = Literal["fail", "replace", "append"]
 
+T = TypeVar("T")
+WhereTypes = Union[Callable[[T], bool], Iterable[Callable[[T], bool]]]
+
 
 class IStatements[T: Table](ABC):
     @abstractmethod
@@ -45,7 +49,6 @@ class IStatements[T: Table](ABC):
     def insert(self, values: T | list[T]) -> None: ...
 
     # endregion
-
     # region upsert
     @overload
     def upsert(self, values: T) -> None:
@@ -76,25 +79,26 @@ class IStatements[T: Table](ABC):
     def update(self, dicc: dict[str | property, Any]) -> None: ...
 
     # endregion
-
     # region limit
     @abstractmethod
     def limit(self, number: int) -> IStatements[T]: ...
 
     # endregion
-
     # region offset
     @abstractmethod
     def offset(self, number: int) -> IStatements[T]: ...
 
     # endregion
-
     # region count
     @abstractmethod
-    def count(self, selection: Callable[[T], property]) -> int: ...
+    def count(
+        self,
+        selection: Callable[[T], property],
+        alias: bool = ...,
+        alias_name: Optional[str] = ...,
+    ) -> int: ...
 
     # endregion
-
     # region delete
     @overload
     def delete(self) -> None: ...
@@ -108,28 +112,15 @@ class IStatements[T: Table](ABC):
     def delete(self, instance: Optional[T | list[T]] = None) -> None: ...
 
     # endregion
-
     # region join
     @abstractmethod
     def join(self, table_left: Table, table_right: Table, *, by: str) -> IStatements[T]: ...
 
     # endregion
-
     # region where
-    @overload
-    def where(self, lambda_: Callable[[T], bool]) -> IStatements[T]:
-        """
-        This method creates where clause by passing the lambda's condition
-
-        EXAMPLE
-        -
-        mb = BaseModel()
-        mb.where(lambda a: 10 <= a.city_id <= 100)
-        """
-        ...
 
     @overload
-    def where(self, lambda_: Callable[[T], Iterable]) -> IStatements[T]:
+    def where(self, conditions: Iterable[Callable[[T], bool]]) -> IStatements[T]:
         """
         This method creates where clause by passing the Iterable in lambda function
         EXAMPLE
@@ -140,7 +131,7 @@ class IStatements[T: Table](ABC):
         ...
 
     @overload
-    def where(self, lambda_: Callable[[T], bool], **kwargs) -> IStatements[T]:
+    def where(self, conditions: Callable[[T], bool], **kwargs) -> IStatements[T]:
         """
         PARAM
         -
@@ -157,10 +148,9 @@ class IStatements[T: Table](ABC):
         ...
 
     @abstractmethod
-    def where(self, lambda_: Callable[[T], bool] = lambda: None, **kwargs) -> IStatements[T]: ...
+    def where(self, conditions: WhereTypes = lambda: None, **kwargs) -> IStatements[T]: ...
 
     # endregion
-
     # region order
     @overload
     def order[TValue](self, _lambda_col: Callable[[T], TValue]) -> IStatements[T]: ...
@@ -170,7 +160,38 @@ class IStatements[T: Table](ABC):
     def order[TValue](self, _lambda_col: Callable[[T], TValue], order_type: OrderType) -> IStatements[T]: ...
 
     # endregion
+    # region concat
+    @overload
+    def concat[*Ts](self, selector: Callable[[T], tuple[*Ts]]) -> IAggregate[T]: ...
 
+    # endregion
+    # region max
+    @overload
+    def max[TProp](
+        self,
+        column: Callable[[T], TProp],
+        alias: bool = ...,
+        alias_name: Optional[str] = ...,
+    ) -> TProp: ...
+    # endregion
+    # region min
+    @overload
+    def min[TProp](
+        self,
+        column: Callable[[T], TProp],
+        alias: bool = ...,
+        alias_name: Optional[str] = ...,
+    ) -> TProp: ...
+    # endregion
+    # region sum
+    @overload
+    def sum[TProp](
+        self,
+        column: Callable[[T], TProp],
+        alias: bool = ...,
+        alias_name: Optional[str] = ...,
+    ) -> TProp: ...
+    # endregion
     # region select
     @overload
     def select(self) -> tuple[T, ...]: ...
@@ -212,7 +233,6 @@ class IStatements[T: Table](ABC):
     def select[TValue, TFlavour, *Ts](self, selector: Optional[Callable[[T], tuple[TValue, *Ts]]] = lambda: None, *, flavour: Type[TFlavour] = None, by: JoinType = JoinType.INNER_JOIN): ...
 
     # endregion
-
     # region select_one
     @overload
     def select_one(self) -> T: ...
@@ -234,10 +254,9 @@ class IStatements[T: Table](ABC):
     def select_one[TValue, TFlavour, *Ts](self, selector: Optional[Callable[[T], tuple[TValue, *Ts]]] = lambda: None, *, flavour: Type[TFlavour] = None, by: Optional[Enum] = JoinType.INNER_JOIN): ...
 
     # endregion
-
     # region group_by
     @abstractmethod
-    def group_by[TRepo, *Ts](self, column: Callable[[T], TRepo], select_query: Callable[[T], tuple[*Ts]]) -> tuple[tuple[*Ts]]: ...
+    def group_by[TRepo, *Ts](self, column: Callable[[T], TRepo]) -> IStatements[T]: ...
 
     # endregion
 
