@@ -128,11 +128,13 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return self
 
     @override
-    def count(self, selection: Callable[[T], tuple] = lambda x: "*") -> int:
-        count_select: IQuery = Select[T](self._model, lambda x: Count[T](self._model, selection))
-        self._query_list["select"].append(count_select)
-        query = self._build()
-        return self.repository.read_sql(query)[0][0]
+    def count(
+        self,
+        selection: Callable[[T], tuple] = lambda x: "*",
+        alias=True,
+        alias_name=None,
+    ) -> IQuery:
+        return Count[T](self._model, selection, alias=alias, alias_name=alias_name)
 
     @override
     def join(self, table_left: Table, table_right: Table, *, by: str) -> IStatements_two_generic[T, MySQLConnection]:
@@ -172,6 +174,10 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
     def min[TProp](self, column: Callable[[T], TProp], alias: bool = True, alias_name: str = "min") -> TProp:
         return func.Min[T](self._model, column=column, alias=alias, alias_name=alias_name)
 
+    @override
+    def sum[TProp](self, column: Callable[[T], TProp], alias: bool = True, alias_name: str = "sum") -> TProp:
+        return func.Sum[T](self._model, column=column, alias=alias, alias_name=alias_name)
+
     @override
     def select[TValue, TFlavour, *Ts](self, selector: Optional[Callable[[T], tuple[TValue, *Ts]]] = lambda: None, *, flavour: Optional[Type[TFlavour]] = None, by: JoinType = JoinType.INNER_JOIN):
         if len(inspect.signature(selector).parameters) == 0:
@@ -211,8 +217,14 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return tuple([res[0] for res in response])
 
     @override
-    def group_by[TRepo, *Ts](self, column: Callable[[T], TRepo], select_query: Callable[[T], tuple[*Ts]]) -> tuple[tuple[*Ts]]:
-        return GroupBy[T, TRepo, tuple[*Ts]](self._model, column, select_query)
+    def group_by[*Ts](self, column: str | Callable[[T], Any]) -> IStatements_two_generic[T, MySQLConnection]:
+        if isinstance(column, str):
+            groupby = GroupBy[T, tuple[*Ts]](self._model, lambda x: column)
+        else:
+            groupby = GroupBy[T, tuple[*Ts]](self._model, column)
+        # Only can be one LIMIT SQL parameter. We only use the last LimitQuery
+        self._query_list["group by"].append(groupby)
+        return self
 
     @override
     def _build(self) -> str:
